View source: R/cacheDirectories.R
| addCacheSearchEnvironment | R Documentation |
Append a new Environment name (a character string) to a global option which is a vector of such names. SimpleCache will search all of these environments to check if a cache is previously loaded, before reloading it.
addCacheSearchEnvironment(addEnv)
addEnv |
Environment to append to the shared cache search list |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.