getCacheDir: Fetcher of the currently set cache directory.

View source: R/cacheDirectories.R

getCacheDirR Documentation

Fetcher of the currently set cache directory.

Description

getCacheDir retrieves the value of the option that stores the currently set cache directory path.

Usage

getCacheDir()

Value

If the option is set, the path to the currently set cache directory; otherwise, NULL.


simpleCache documentation built on March 2, 2026, 1:06 a.m.