resetCacheSearchEnvironment: Sets global option of cache search environments to 'NULL'.

View source: R/cacheDirectories.R

resetCacheSearchEnvironmentR Documentation

Sets global option of cache search environments to NULL.

Description

Sets global option of cache search environments to NULL.

Usage

resetCacheSearchEnvironment()

simpleCache documentation built on March 2, 2026, 1:06 a.m.