secToTime: This function takes a time in seconds and converts it to a...

View source: R/utility.R

secToTimeR Documentation

This function takes a time in seconds and converts it to a more human-readable format, showing hours, minutes, or seconds, depending on how long the time is. Used by my implementation of tic()/toc().

Description

This function takes a time in seconds and converts it to a more human-readable format, showing hours, minutes, or seconds, depending on how long the time is. Used by my implementation of tic()/toc().

Usage

secToTime(timeInSec)

Arguments

timeInSec

numeric value of time measured in seconds.


simpleCache documentation built on March 2, 2026, 1:06 a.m.