setCacheBuildDir: Sets local cache build directory with scripts for building...

View source: R/cacheDirectories.R

setCacheBuildDirR Documentation

Sets local cache build directory with scripts for building files.

Description

Sets local cache build directory with scripts for building files.

Usage

setCacheBuildDir(cacheBuildDir = NULL)

Arguments

cacheBuildDir

Directory where build scripts are stored.


simpleCache documentation built on March 2, 2026, 1:06 a.m.