setSharedCacheDir: Set shared cache directory

View source: R/cacheDirectories.R

setSharedCacheDirR Documentation

Set shared cache directory

Description

Sets global variable specifying the default cache directory for simpleCacheShared calls; this function is simply a helper alias for caching results that will be used across projects.

Usage

setSharedCacheDir(sharedCacheDir = NULL)

Arguments

sharedCacheDir

Directory where shared caches should be stored


simpleCache documentation built on March 2, 2026, 1:06 a.m.