simpleCacheGlobal: Helper alias for loading caches into the global environment....

View source: R/sharedCaches.R

simpleCacheGlobalR Documentation

Helper alias for loading caches into the global environment. simpleCache normally loads variables into the calling environment; this ensures that the variables are loaded in the global environment.

Description

Helper alias for loading caches into the global environment. simpleCache normally loads variables into the calling environment; this ensures that the variables are loaded in the global environment.

Usage

simpleCacheGlobal(...)

Arguments

...

Parameters passed to simpleCache.


simpleCache documentation built on March 2, 2026, 1:06 a.m.