simpleCacheSharedGlobal: Helper alias for loading shared caches into the global...

View source: R/sharedCaches.R

simpleCacheSharedGlobalR Documentation

Helper alias for loading shared caches into the global environment.

Description

Helper alias for loading shared caches into the global environment.

Usage

simpleCacheSharedGlobal(...)

Arguments

...

Parameters passed to simpleCache.


simpleCache documentation built on March 2, 2026, 1:06 a.m.