toc: Check the time since the current timer was started with tic()

View source: R/utility.R

tocR Documentation

Check the time since the current timer was started with tic()

Description

Check the time since the current timer was started with tic()

Usage

toc()

simpleCache documentation built on March 2, 2026, 1:06 a.m.