View source: R/cacheDirectories.R
| setSharedCacheDir | R Documentation |
Sets global variable specifying the default cache directory for
simpleCacheShared calls; this function is simply a helper alias for caching
results that will be used across projects.
setSharedCacheDir(sharedCacheDir = NULL)
sharedCacheDir |
Directory where shared caches should be stored |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.